@@ -261,7 +261,7 @@ def test_BlueprintOutput():
     assert blueprint_out == blueprint_out
 
 
-def test_auto_trigger_selection(caplog):
+def test_auto_trigger_selection_text(caplog):
     """Test auto_trigger_selection."""
     test_time = np.array([0, 1, 2, 3, 4])
     test_trigger = np.array([0, 1, 2, 3, 4])
@@ -284,14 +284,36 @@ def test_auto_trigger_selection(caplog):
                                 test_units, test_chtrig)
     assert phys_in.trigger_idx == 1
     # test when no trigger is found
-    test_chn_name = ['time', 'TRIGGAH', 'half', 'CO2', 'CO 2', 'strigose']
-    with raises(Exception) as errorinfo:
-        phys_in = po.BlueprintInput(test_timeseries, test_freq, test_chn_name,
-                                    test_units, test_chtrig)
-        assert 'No trigger channel automatically found' in str(errorinfo.value)
-    # test when no trigger is found
     test_chn_name = ['time', 'trigger', 'TRIGGER', 'CO2', 'CO 2', 'strigose']
     with raises(Exception) as errorinfo:
         phys_in = po.BlueprintInput(test_timeseries, test_freq, test_chn_name,
                                     test_units, test_chtrig)
         assert 'More than one possible trigger channel' in str(errorinfo.value)
+
+
+def test_auto_trigger_selection_time():
+    """Test auto_trigger_selection in time domain."""
+    # Simulate 10 s of a trigger, O2 and ECG
+    T = 10
+    nSamp = 100
+    fs = nSamp/T
+    test_time = np.linspace(0, T, nSamp)
+    test_freq = [fs, fs, fs, fs]
+
+    # O2 as a sinusoidal of 0.5 Hz
+    test_O2 = np.sin(2*np.pi*0.5*test_time)
+    # ECG as a sinusoidal with 1.5 Hz
+    test_ecg = np.sin(2*np.pi*1.5*test_time)
+    # Trigger as a binary signal
+    test_trigger = np.zeros(nSamp)
+    test_trigger[1:nSamp:4] = 1
+
+    test_timeseries = [test_time, test_O2, test_ecg, test_trigger]
+    test_chn_name = ['time', 'O2', 'ecg', 'tiger']
+    test_units = ['s', 'V', 'V', 'V']
+
+    # test when chtrig is 0 and the trigger is not recognized by text matching:
+    test_chtrig = 0
+    phys_in = po.BlueprintInput(test_timeseries, test_freq, test_chn_name,
+                                test_units, test_chtrig)
+    assert phys_in.trigger_idx == 3
